[chronojump] Chronojump networks client can be minimized



commit 92ee339388b36a5b3350025ca0246ba57008505a
Author: Xavier de Blas <xaviblas gmail com>
Date:   Tue Mar 27 22:00:18 2018 +0200

    Chronojump networks client can be minimized

 .../photocells-double-contact-workflow.dia         |  Bin 9644 -> 9594 bytes
 glade/app1.glade                                   |   60 +++++++++++++++++++-
 images/md/ic_fullscreen_exit_blue_24dp_1x.png      |  Bin 0 -> 192 bytes
 src/Makefile.am                                    |    1 +
 src/gui/chronojump.cs                              |    6 ++-
 src/gui/chronojumpIcons.cs                         |    6 ++
 6 files changed, 70 insertions(+), 3 deletions(-)
---
diff --git a/diagrams/processes/photocells-double-contact-workflow.dia 
b/diagrams/processes/photocells-double-contact-workflow.dia
index a254eca..d793d11 100644
Binary files a/diagrams/processes/photocells-double-contact-workflow.dia and 
b/diagrams/processes/photocells-double-contact-workflow.dia differ
diff --git a/glade/app1.glade b/glade/app1.glade
index c50541c..9b8d710 100644
--- a/glade/app1.glade
+++ b/glade/app1.glade
@@ -1640,6 +1640,9 @@
                                                             <placeholder/>
                                                             </child>
                                                             <child>
+                                                            <placeholder/>
+                                                            </child>
+                                                            <child>
                                                             <widget class="GtkLabel" 
id="label_start_selector_jumps">
                                                             <property name="visible">True</property>
                                                             <property name="can_focus">False</property>
@@ -3984,6 +3987,31 @@ EncoderInertialCapture</property>
                                                   </packing>
                                                 </child>
                                                 <child>
+                                                  <widget class="GtkButton" 
id="button_preferences_not_menu_minimize">
+                                                    <property name="width_request">50</property>
+                                                    <property name="visible">True</property>
+                                                    <property name="can_focus">True</property>
+                                                    <property name="can_default">True</property>
+                                                    <property name="receives_default">True</property>
+                                                    <property name="has_tooltip">True</property>
+                                                    <property name="relief">half</property>
+                                                    <signal name="clicked" 
handler="on_button_minimize_clicked" swapped="no"/>
+                                                    <child>
+                                                      <widget class="GtkImage" id="image_minimize">
+                                                        <property name="visible">True</property>
+                                                        <property name="can_focus">False</property>
+                                                        <property name="stock">gtk-missing-image</property>
+                                                        <property name="icon-size">2</property>
+                                                      </widget>
+                                                    </child>
+                                                  </widget>
+                                                  <packing>
+                                                    <property name="expand">True</property>
+                                                    <property name="fill">True</property>
+                                                    <property name="position">2</property>
+                                                  </packing>
+                                                </child>
+                                                <child>
                                                   <widget class="GtkButton" 
id="button_preferences_not_menu_quit1">
                                                     <property name="width_request">50</property>
                                                     <property name="visible">True</property>
@@ -4005,7 +4033,7 @@ EncoderInertialCapture</property>
                                                   <packing>
                                                     <property name="expand">True</property>
                                                     <property name="fill">True</property>
-                                                    <property name="position">2</property>
+                                                    <property name="position">3</property>
                                                   </packing>
                                                 </child>
                                               </widget>
@@ -18017,6 +18045,31 @@ Concentric</property>
                                                   </packing>
                                                 </child>
                                                 <child>
+                                                  <widget class="GtkButton" 
id="button_preferences_not_menu_minimize1">
+                                                    <property name="width_request">50</property>
+                                                    <property name="visible">True</property>
+                                                    <property name="can_focus">True</property>
+                                                    <property name="can_default">True</property>
+                                                    <property name="receives_default">True</property>
+                                                    <property name="has_tooltip">True</property>
+                                                    <property name="relief">half</property>
+                                                    <signal name="clicked" 
handler="on_button_minimize_clicked" swapped="no"/>
+                                                    <child>
+                                                      <widget class="GtkImage" id="image_minimize1">
+                                                        <property name="visible">True</property>
+                                                        <property name="can_focus">False</property>
+                                                        <property name="stock">gtk-missing-image</property>
+                                                        <property name="icon-size">2</property>
+                                                      </widget>
+                                                    </child>
+                                                  </widget>
+                                                  <packing>
+                                                    <property name="expand">True</property>
+                                                    <property name="fill">True</property>
+                                                    <property name="position">2</property>
+                                                  </packing>
+                                                </child>
+                                                <child>
                                                   <widget class="GtkButton" 
id="button_preferences_not_menu_quit">
                                                     <property name="width_request">50</property>
                                                     <property name="visible">True</property>
@@ -18038,7 +18091,7 @@ Concentric</property>
                                                   <packing>
                                                     <property name="expand">True</property>
                                                     <property name="fill">True</property>
-                                                    <property name="position">2</property>
+                                                    <property name="position">3</property>
                                                   </packing>
                                                 </child>
                                               </widget>
@@ -24851,6 +24904,9 @@ then click this button.</property>
                                                             <child>
                                                             <placeholder/>
                                                             </child>
+                                                            <child>
+                                                            <placeholder/>
+                                                            </child>
                                                             </widget>
                                                             <packing>
                                                             <property name="expand">False</property>
diff --git a/images/md/ic_fullscreen_exit_blue_24dp_1x.png b/images/md/ic_fullscreen_exit_blue_24dp_1x.png
new file mode 100644
index 0000000..4b3ace0
Binary files /dev/null and b/images/md/ic_fullscreen_exit_blue_24dp_1x.png differ
diff --git a/src/Makefile.am b/src/Makefile.am
index 547d8c1..2fd0bda 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -407,6 +407,7 @@ RESOURCES = \
        ../images/md/ic_delete_blue_24dp_1x.png,stock_delete.png \
        ../images/md/ic_create_new_folder_blue_24dp_2x.png,folder_new_big.png \
        ../images/md/ic_create_new_folder_blue_24dp_1x.png,folder_new.png \
+       ../images/md/ic_fullscreen_exit_blue_24dp_1x.png,image_minimize.png \
        ../images/md/ic_folder_open_blue_24dp_2x.png,folder_open_big.png \
        ../images/md/ic_folder_open_blue_24dp_1x.png,folder_open.png \
        ../images/md/ic_visibility_blue_24dp_1x.png,image_visibility.png \
diff --git a/src/gui/chronojumpIcons.cs b/src/gui/chronojumpIcons.cs
index d5bedad..31d8bf4 100644
--- a/src/gui/chronojumpIcons.cs
+++ b/src/gui/chronojumpIcons.cs
@@ -31,6 +31,8 @@ public partial class ChronoJumpWindow
        [Widget] Gtk.Image image_home1;
        [Widget] Gtk.Image image_settings;
        [Widget] Gtk.Image image_settings1;
+       [Widget] Gtk.Image image_minimize;
+       [Widget] Gtk.Image image_minimize1;
        [Widget] Gtk.Image image_quit;
        [Widget] Gtk.Image image_quit1;
        [Widget] Gtk.Image image_quit2;
@@ -157,6 +159,10 @@ public partial class ChronoJumpWindow
                image_settings1.Pixbuf = pixbuf;
                image_session_preferences.Pixbuf = pixbuf;
 
+               pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_minimize.png");
+               image_minimize.Pixbuf = pixbuf;
+               image_minimize1.Pixbuf = pixbuf;
+
                pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_quit.png");
                image_quit.Pixbuf = pixbuf;
                image_quit1.Pixbuf = pixbuf;


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/gui/chronojump.cs b/src/gui/chronojump.cs
index e2686e5..d998f80 100644
--- a/src/gui/chronojump.cs
+++ b/src/gui/chronojump.cs
@@ -2110,10 +2110,14 @@ public partial class ChronoJumpWindow
 
 
        /* ---------------------------------------------------------
         * ----------------  DELETE EVENT, QUIT  -----------------------
         *  --------------------------------------------------------
         */
 
+       private void on_button_minimize_clicked (object o, EventArgs args) {
+               app1.Iconify();
+       }
+
        private void on_delete_event (object o, DeleteEventArgs args) {
                args.RetVal = true;
 
@@ -2110,10 +2110,14 @@ public partial class ChronoJumpWindow
 
        /* ---------------------------------------------------------
-        * ----------------  DELETE EVENT, QUIT  -----------------------
+        * ----------------  MINIMIZE, DELETE EVENT, QUIT  ---------
         *  --------------------------------------------------------
         */